
# Utility Functions
::: fdtdx.utils.Logger
A logger which can automatically record important metrics during optimization. For a detailed guide on the usage, see the example scripts in the github repository.

::: fdtdx.utils.plot_setup.plot_setup
Plots an image of the simulation scene using matplotlib. This is very helpful for veryfying the correct positions of all objects in the simulation scene.

